.. index::
   single: Function reference; ClusterExpansion
   single: Class reference; ClusterExpansion

Cluster expansions
==================

.. autoclass:: icet.ClusterExpansion
   :members:
   :undoc-members:
   :inherited-members:
   :noindex:
